"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _vue = _interopRequireDefault(require("vue"));

var _vuexAlong = require("vuex-along");

var _router = _interopRequireDefault(require("./router"));

var _store = _interopRequireDefault(require("./store"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var HOOK_KEYS = Object.freeze({
  beforeEach: true,
  beforeResolve: true,
  afterEach: true,
  onReady: true,
  onError: true
});
var _default = {
  start: function start(moduleConfig) {
    var application = moduleConfig.getApplication();
    var vuexAlong = {};
    vuexAlong.name = "vuexAlong:".concat(application.name, "-").concat(application.version);
    var local = [];
    var session = [];
    var configs = moduleConfig.getExtension('vuex.modules');

    for (var key in configs) {
      var m = configs[key];

      _store.default.registerModule(key, m);

      if (m.storage) {
        if (m.storage === 'session') {
          session.push(key);
        } else if (m.storage === 'local') {
          local.push(key);
        }
      }
    }

    if (session.length > 0) {
      vuexAlong.session = {
        list: session
      };
    }

    if (local.length > 0) {
      vuexAlong.local = {
        list: local
      };
    } else {
      vuexAlong.justSession = true;
    }

    (0, _vuexAlong.createVuexAlong)(vuexAlong)(_store.default);
    configs = moduleConfig.getExtension('vue.plugins');

    for (var _key in configs) {
      _vue.default.use(configs[_key]);
    }

    var options = [];
    configs = moduleConfig.getExtension('vue.options');

    for (var _key2 in configs) {
      options.push(configs[_key2]);
    }

    configs = moduleConfig.getExtension('vue.router.routes');
    var routes = [];
    var parentRoutes = {};
    var unresolved = {};

    function registerParentRoutes(route) {
      if (route.children && route.children.length) {
        var name = route.name;

        if (name === undefined || name === '') {
          console.log("Error: \u8DEF\u7531\u540D\u79F0\u672A\u5B9A\u4E49\uFF0C".concat(JSON.stringify(route)));
          return;
        }

        parentRoutes[name] = route.children;

        if (unresolved[name]) {
          unresolved[name].forEach(function (item) {
            route.children.push(item);
          });
          delete unresolved[name];
        }

        route.children.forEach(function (item) {
          registerParentRoutes(item);
        });
      }
    }

    for (var _key3 in configs) {
      var config = configs[_key3];

      if (config && config.parent && config.routes) {
        (function () {
          var parentName = config.parent;
          var parent = void 0;

          if (parentName === 'root') {
            parent = routes;
          } else {
            parent = parentRoutes[parentName];

            if (!parent) {
              unresolved[parentName] = unresolved[parentName] || [];
              parent = unresolved[parentName];
            }
          }

          config.routes.forEach(function (item) {
            parent.push(item);
            registerParentRoutes(item);
          });
        })();
      }
    }

    for (var _key4 in unresolved) {
      console.log("Error: \u7236\u8DEF\u7531\u201C".concat(_key4, "\u201D\u4E0D\u5B58\u5728"));
    }

    _router.default.addRoutes(routes);

    configs = moduleConfig.getExtension('vue.router.hooks');

    for (var _key5 in configs) {
      var _config = configs[_key5];

      for (var hook in _config) {
        if (HOOK_KEYS[hook]) {
          _router.default[hook](_config[hook]);
        }
      }
    }

    var app = moduleConfig.getExtension('vue.app');
    var vueOptions = {
      router: _router.default,
      store: _store.default,
      mixins: options,
      render: function render(h) {
        return h(app.component);
      }
    };
    new _vue.default(vueOptions).$mount('#app');
  }
};
exports.default = _default;